from libqtile.config import Key, Drag, Click
from libqtile.command import lazy

from groups import group_names

mod = ["mod4"]
modshift = ["mod4", "shift"]
modctrl = ["mod4", "control"]
ctrl = ["control"]

keys = [
    # Standard Controls
    Key(modshift, "d",      lazy.window.kill(), desc='kill active window'),
    Key(modctrl,  "r",      lazy.restart(), desc='reload qtile config'),
    Key(modctrl,  "l",      lazy.spawn('xdg-screensaver lock'), desc='lock screen'),
    Key(modshift, "q",      lazy.spawn('rofi -show p -modi p:rofi-power-menu'), desc="shutdown menu"),
    Key(mod,      "Tab",    lazy.spawn('rofi -show window'), desc='window menu'),

    # Treetab controls
    Key(modctrl,  "Up",     lazy.layout.section_up(), desc='Move up a section in treetab'),
    Key(modctrl,  "Down",   lazy.layout.section_down(), desc='Move down a section in treetab'),

    # Window controls
    Key(mod,      "Up",     lazy.layout.up(), desc='Move focus up in current stack pane'),
    Key(mod,      "Down",   lazy.layout.down(), desc='Move focus down in current stack pane'),
    Key(mod,      "Left",   lazy.layout.shrink(), lazy.layout.decrease_nmaster(), desc='Shrink window (MonadTall), decrease number in master pane (Tile)'),
    Key(mod,      "Right",  lazy.layout.grow(), lazy.layout.increase_nmaster(), desc='Expand window (MonadTall), increase number in master pane (Tile)'),
    Key(modshift, "Down",   lazy.layout.shuffle_down(), desc='Move windows down in current stack'),
    Key(modshift, "Up",     lazy.layout.shuffle_up(), desc='Move windows up in current stack'),
    Key(modctrl,  "f",      lazy.window.toggle_floating(), desc='toggle floating'),
    Key(mod,      "n",      lazy.layout.normalize(), desc='normalize window size ratios'),
    Key(mod,      "m",      lazy.layout.maximize(), desc='toggle window between minimum and maximum sizes'),

    # Stack controls
    Key(modshift, "space",  lazy.layout.rotate(), lazy.layout.flip(), desc='Switch which side main pane occupies (XmonadTall)'),
    Key(mod,      "space",  lazy.layout.next(), desc='Switch window focus to other pane(s) of stack'),
    Key(modctrl,  "Return", lazy.layout.toggle_split(), desc='Toggle between split and unsplit sides of stack'),

    # run programs
    Key(mod,      "Return", lazy.spawn('rofi -show drun'), desc='launcher'),
    Key(modshift, "r",      lazy.spawn('pcmanfm'), desc='filebrowser'),
    Key(modshift, "p",      lazy.spawn('bwmenu'), desc='passwordmenu'),
    Key(ctrl,     "space",  lazy.group["DRP"].dropdown_toggle("term")),

    # sound + brightness
    Key([],       "XF86AudioMute",         lazy.spawn('pactl set-sink-mute @DEFAULT_SINK@ toggle')),
    Key([],       "XF86AudioMicMute",      lazy.spawn('pactl set-source-mute @DEFAULT_SOURCE@ toggle')),
    Key([],       "XF86AudioLowerVolume",  lazy.spawn('pactl set-sink-volume @DEFAULT_SINK@ -5%')),
    Key([],       "XF86AudioRaiseVolume",  lazy.spawn('pactl set-sink-volume @DEFAULT_SINK@ +5%')),
    Key([],       "XF86MonBrightnessUp",   lazy.spawn('brightnessctl set +10%')),
    Key([],       "XF86MonBrightnessDown", lazy.spawn('brightnessctl set 10%-'))
]

mouse = [
    Drag(mod,  "Button1", lazy.window.set_position_floating(), start=lazy.window.get_position()),
    Drag(mod,  "Button3", lazy.window.set_size_floating(), start=lazy.window.get_size()),
    Click(mod, "Button2", lazy.window.bring_to_front())
]

for i, (name, kwargs) in enumerate(group_names, 1):
    keys.append(Key(mod, str(i), lazy.group[name].toscreen()))
    keys.append(Key(modshift, str(i), lazy.window.togroup(name)))
